#!/bin/bash
QP_ROOT= # defines your QP_ROOT variable here 
# Source the quantum package environment
source ${QP_ROOT}/quantum_package.rc
cat << EOF > Li2.xyz
2                                                                                                                         

Li  0.0000  0.0000  -1.3365
Li  0.0000  0.0000  +1.3365
EOF


# Create results directory if it doesn't exist
mkdir -p results

basis=aug-cc-pvdz
EZFIO=Li2_${basis}

# Create EZFIO database
qp_create_ezfio -b $basis -m 1 -o results/${EZFIO} Li2.xyz
# Sets the EZFIO file to be the one targeted
qp set_file results/${EZFIO}

# Always start the calculation with an SCF ! It will help the TC-SCF calculation :)
qp run scf | tee ${EZFIO_FILE}.scf.out  # you should get -14.8698523 in the aug-cc-pvdz

########################################
# JASTROW PARAMETERS FOR TC CALCULATIONS
########################################
# THEORY:
#--------
## Briefly, the TC methodology depends VERY MUCH on the type of the Jastrow factor, specially the CORE electrons 
## as these regions of space are VERY energetic. 
## More precisely, if you naively correlate the CORE electrons with a typical VALENCE correlation hole, 
## you might endup with an energy WAY TOO LOW unless you have a VERY flexible Slater determinant expansion. 

## There exists MANY types of Jastrow, either highly parametrized or loosly parametrized. 
## In the case of the highly parametrized Jastrow, the parameters must be found by rather complex optimization, 
## often based on VMC calculations, and this must be done FOR EACH SYSTEM, i.e. EACH MOLECULAR GEOMETRY. 

## Alternatively, we designed a "simple" Jastrow which is quite efficiently TRANSFERABLE from ATOMS to MOLECULES, 
## and it is of course available in QP2 (https://doi.org/10.1021/acs.jctc.3c00257). 

## It is expressed as TWO-BODY UNIVERSAL VALENCE Jastrow j(mu,r12) (https://doi.org/10.1063/5.0044683)
## multiplied by ATOM CENTERED GAUSSIAN ENVELOPES CANCELLING j(mu,r12) in the CORE regions, namely
# J(r1,r2) = G(r1)G(r2) j(mu,r12), with G(r1) = 1 - \sum_{A in nuclei} e^{-alpha_A r_{1A}^2}. 

## The typical RANGE of the two-body Jastrow is determined by "mu" in the previous equation, 
## and the exponents of GAUSSIAN ENVELOPES "alpha_A" is atom dependent (and potentially basis set dependent). 

## Nevertheless, in the JCTC paper of 2023, we proposed to use mu=0.87 (typical for valence correlation) 
## and we optimized alpha_A parameters for the Li-Ne series, together with some 3d atoms. 
## You can pick up the values at the minimum for the curves in the JCTC paper, or more simply refer to 
## that table extracted from Table I of https://doi.org/10.1063/5.0163831 
#Atom       & H        &  Li &   C &   N &   O &   F &  Ne \\
#$\alpha_m$ & 100      & 5.5 & 2.5 & 2.5 & 2.0 & 2.0 & 2.0 \\


# Typical parameters for your calculations:
#------------------------------------------
# SIMPLE JASTROW FACTOR 
#----------------------
## The default Jastrow is the "simple" one previsously described. 
## You must set one parameter "mu_erf" for the TWO-BODY Jastrow, which is 0.87 
qp set hamiltonian mu_erf 0.87 

## Then you must set the EXPONENTS of the ENVELOPES for EACH ATOM. In the case of Li, a value of 5.5 is reasonable. 
qp set jastrow env_expo "[5.5, 5.5]" 
## Then you 

# NUMERICAL INTEGRATION
#----------------------
## The integrals in TC are rarely analytic, and even when they are, it is often more efficient to compute them NUMERICALLY
qp set tc_keywords tc_integ_type numeric


# Computes all integrals numerically, more efficient and similar results than semi analytical form
qp set tc_keywords tc_integ_type numeric
# Write the TC integrals in the EZFIO folder once computed, in order to avoid recomputation each time 
qp set tc_keywords io_tc_integ Write

############## ACTUAL TC CALCULATION
# Edit EZFIO database
qp edit -c 
# Run tc_scf
qp run tc_scf | tee ${EZFIO_FILE}.tc_scf_output # you should get around -14.89857

# Run TC FCI
qp run fci_tc_bi_ortho | tee ${EZFIO_FILE}.tc_fci_output # you should get around -14.93028
## As a comparison, for Li2 at the geometry provided, 
## the FCI energy in the aug-cc-pVDZ basis  is of                                -14.90183, 
## the FCI energy in the aug-cc-pCVQZ (so with CORE functions) is of             -14.990(1).
